import { createCommand } from '../../../types';
import { showSubcommand } from './show';
import { getCommand } from '../../../command-prefix';
export const capabilitiesCommand = createCommand({
    name: 'capabilities',
    description: 'Show CLI capabilities and available tasks',
    tags: ['read-only', 'fast'],
    examples: [
        { command: getCommand('ai capabilities show'), description: 'Show CLI capabilities' },
    ],
    subcommands: [showSubcommand],
});
export default capabilitiesCommand;
//# sourceMappingURL=index.js.map