import type { Logger } from '@agentuity/core';
export interface CIBuildOptions {
    url?: string;
    directory?: string;
    trigger?: string;
    event?: string;
    message?: string;
    commit?: string;
    commitUrl?: string;
    branch?: string;
    repo?: string;
    provider?: string;
    pullRequestNumber?: number;
    pullRequestUrl?: string;
    logsUrl?: string;
}
export declare function runCIBuild(opts: CIBuildOptions, _logger: Logger): Promise<void>;
//# sourceMappingURL=ci.d.ts.map