import type { Logger, BuildMetadata } from '../../types';
import type { APIClient } from '../../api';
interface IDevmodeSyncService {
    sync(currentMetadata: BuildMetadata, previousMetadata: BuildMetadata | undefined, projectId: string, deploymentId: string): Promise<void>;
}
export declare function createDevmodeSyncService({ logger, apiClient, mock, }: {
    logger: Logger;
    apiClient: APIClient | null;
    mock?: boolean;
}): IDevmodeSyncService;
export {};
//# sourceMappingURL=sync.d.ts.map