export type HubInitProbeResult = {
    ok: true;
} | {
    ok: false;
    code: 'unauthorized' | 'http_error' | 'invalid_response' | 'network_error';
    message: string;
};
export declare function probeHubInitAccess(hubHttpUrl: string, options?: {
    apiKey?: string | null;
    orgId?: string | null;
    fetchImpl?: typeof fetch;
}): Promise<HubInitProbeResult>;
//# sourceMappingURL=tui-init.d.ts.map