interface GravityClient {
    filename: string;
    version: string;
}
/**
 *
 * @returns full path to the downloaded file
 */
export declare function download(gravityDir: string): Promise<GravityClient>;
export {};
//# sourceMappingURL=download.d.ts.map