import { z } from 'zod';
export declare const EmailInboundSchema: z.ZodObject<{
    id: z.ZodString;
    from: z.ZodString;
    to: z.ZodString;
    subject: z.ZodOptional<z.ZodString>;
    text: z.ZodOptional<z.ZodString>;
    html: z.ZodOptional<z.ZodString>;
    received_at: z.ZodOptional<z.ZodString>;
    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    attachments: z.ZodOptional<z.ZodArray<z.ZodUnknown>>;
}, z.core.$strip>;
//# sourceMappingURL=schemas.d.ts.map