interface Options {
    progress?: (val: number) => void;
    filter?: (filename: string, relative: string) => boolean;
}
export declare function zipDir(dir: string, outdir: string, options?: Options): Promise<void>;
export {};
//# sourceMappingURL=zip.d.ts.map