export declare const SNAPSHOT_TAG_REGEX: RegExp;
export declare const MAX_SNAPSHOT_TAG_LENGTH = 128;
interface FileEntry {
    path: string;
    absolutePath: string;
    size: number;
}
export declare const DEFAULT_EXCLUSIONS: string[];
export declare function resolveFileGlobs(directory: string, patterns: string[]): Promise<Map<string, FileEntry>>;
export declare const buildSubcommand: import("../../../..").CommandDefinition;
export default buildSubcommand;
//# sourceMappingURL=build.d.ts.map