/**
 * Build-time ID generation utilities.
 *
 * Pure hash functions for generating deterministic IDs.
 * No AST parsing — just SHA1 hashing.
 */
/**
 * Generate a deterministic deployment ID for devmode.
 */
export declare function getDevmodeDeploymentId(projectId: string, endpointId: string): string;
//# sourceMappingURL=ids.d.ts.map