import { type Logger, VectorStorageService } from '@agentuity/core';
import type { AuthData, Config, GlobalOptions, ProjectConfig } from '../../../types';
export declare function createStorageAdapter(ctx: {
    logger: Logger;
    auth: AuthData;
    region: string;
    project?: ProjectConfig;
    config: Config | null;
    options: GlobalOptions;
}, explicitOrgId?: string): VectorStorageService;
//# sourceMappingURL=util.d.ts.map