/**
 * Stream a ReadableStream of raw bytes to a file on disk.
 *
 * This mirrors the pattern used by the deploy fork wrapper to capture child
 * process stdout/stderr without accumulating the output in memory.  Returns
 * the total number of bytes written.
 */
export declare function captureStreamToFile(stream: ReadableStream<Uint8Array>, filePath: string): Promise<number>;
//# sourceMappingURL=stream-capture.d.ts.map