export interface PatchFunctionAction {
    before?: string;
    after?: string;
}
export interface PatchClassAction {
    methods: Record<string, PatchFunctionAction>;
}
export interface PatchModule {
    module: string;
    filename?: string;
    functions?: Record<string, PatchFunctionAction>;
    classes?: Record<string, PatchClassAction>;
    body?: PatchFunctionAction;
}
export declare function generateEnvWarning(envkey: string): string;
export declare function generateJSArgsPatch(index: number, inject: string): string;
export declare function generateEnvGuard(name: string, inject: string, alt?: string): string;
export declare function generateGatewayEnvGuard(apikey: string, _apikeyval: string, apibase: string, provider: string): string;
/**
 * Build a RegExp filter for a Bun build plugin that matches a patch module's
 * file path inside node_modules. The pattern matches both forward-slash (Unix)
 * and backslash (Windows) path separators.
 */
export declare function buildPatchFilter(module: string, filename?: string): RegExp;
export declare function searchBackwards(contents: string, offset: number, val: string): number;
//# sourceMappingURL=_util.d.ts.map