/**
 * Ensures bun is available on PATH by checking common install locations.
 * If bun is not on PATH but exists in $HOME/.bun/bin, adds it to process.env.PATH.
 *
 * This handles the case where the install script installs bun to $HOME/.bun/bin
 * but the user hasn't restarted their shell yet, so it's not on PATH.
 */
export declare function ensureBunOnPath(): Promise<void>;
//# sourceMappingURL=bun-path.d.ts.map