export interface ClaudeSettings {
    permissions?: {
        allow?: string[];
        deny?: string[];
    };
    [key: string]: unknown;
}
export declare const CLAUDE_DIR: string;
export declare const CLAUDE_SETTINGS_FILE: string;
export declare const PLUGIN_INSTALL_DIR: string;
export declare const AGENTUITY_ALLOW_PERMISSIONS: string[];
export declare const AGENTUITY_DENY_PERMISSIONS: string[];
//# sourceMappingURL=constants.d.ts.map